gs_quant.timeseries.datetime.prepend — gs_quant 0.1 documentation

# gs_quant.timeseries.datetime.prepend

`prepend`(x)

  Prepend data series

  Parameters

    x (`List`[`Series`]) – an array of timeseries

  Return type

    `Series`

  Returns

    concatenated timeseries

  Usage

  For input series [\(x_1\), \(x_2\), … , \(X_n\)], takes data from series \(X_i\) until the first date for which \(X_{i+1}\) has data, useful when a higher quality series has a shorter history than a lower quality series.

  Examples

  Prepend two series:

      >>> x = generate_series(100)
      >>> y = generate_series(100)
      >>> prepend([x, y])

  See also

  `union()`